@@ -10,11 +10,14 @@ class lines:
 					subplot=None, xlim=None, ylim=None, xTextShift=0.05, yTextShift=0.95,
 					ticker_fontsize=9, xTextLoc=None, yTextLoc=None, color='blue', marker=',', show=True, 
 					xticker_rotate=0, yticker_rotate=0,
+					vertical_axis_loc=None, horizontal_axis_loc=None,
+					vertical_axis_color='k', horizontal_axis_color='k',
 					xtick_locations=None, xtick_labels=None, ytick_locations=None, ytick_labels=None, 
-					title_font=16, xfont=16, yfont=16, figsize=None):
+					title_font=16, xfont=16, yfont=16, figsize=None, grid=False, fill_area=None):
 		"""calculates the probability that "token" is found in spam emails
 		
 		:param token: (str)
+						xlim=(0,5) ylim=(0,5)
 		:return: (float) probability "token" is spam based on training emails
 		"""
 		font = {'family' : 'normal', 'weight' : 'bold', 'size'   : title_font}
@@ -24,20 +27,26 @@ class lines:
 		self.xfont = xfont
 		self.yfont = yfont
 		self.already_called_plot_line = False
+		self.X = X
+		self.Y = Y
 
 		if figsize is not None: plt.figure(figsize=figsize)
 
-		self.plot_line(X=X, Y=Y, title=title, xlabel=xlabel, ylabel=ylabel, imgText=imgText, outpath=outpath, 
+		self.add_line(X=X, Y=Y, title=title, xlabel=xlabel, ylabel=ylabel, imgText=imgText, outpath=outpath, 
 					subplot=subplot, xlim=xlim, ylim=ylim, xTextShift=xTextShift, yTextShift=yTextShift,
 					ticker_fontsize=ticker_fontsize, xTextLoc=xTextLoc, yTextLoc=yTextLoc, color=color, 
 					marker=marker, show=show, xticker_rotate=xticker_rotate, yticker_rotate=yticker_rotate,
+					vertical_axis_loc=vertical_axis_loc, horizontal_axis_loc=horizontal_axis_loc,
+					vertical_axis_color=vertical_axis_color, horizontal_axis_color=horizontal_axis_color,
 					xtick_locations=xtick_locations, xtick_labels=xtick_labels, 
-					ytick_locations=ytick_locations, ytick_labels=ytick_labels)
+					ytick_locations=ytick_locations, ytick_labels=ytick_labels, grid=grid, fill_area=fill_area)
 
-	def plot_line(self, X, Y, title, xlabel, ylabel, imgText=None, outpath=None, 
+	def add_line(self, X, Y, title, xlabel, ylabel, imgText=None, outpath=None, 
 					subplot=None, xlim=None, ylim=None, xTextShift=0.05, yTextShift=0.95,
 					ticker_fontsize=9, xTextLoc=None, yTextLoc=None, color='blue', marker=',', show=True, 
-					xticker_rotate=0, yticker_rotate=0,
+					xticker_rotate=0, yticker_rotate=0, grid=False, fill_area=None,
+					vertical_axis_loc=None, horizontal_axis_loc=None,
+					vertical_axis_color='k', horizontal_axis_color='k',
 					xtick_locations=None, xtick_labels=None, ytick_locations=None, ytick_labels=None):
 		"""create a default 2D line plot
 		
@@ -67,6 +76,9 @@ class lines:
 		#plt.tick_params(axis='both', which='both', labelsize=ticker_fontsize)
 		plt.xticks(ticks=xtick_locations, labels=xtick_labels, fontsize=ticker_fontsize, rotation=xticker_rotate)
 		plt.yticks(fontsize=ticker_fontsize, rotation=yticker_rotate, ticks=ytick_locations, labels=ytick_labels )
+		plt.grid(grid)
+		
+		if fill_area is not None: self.fill_area(fill_area[0],fill_area[1],fill_area[2])
 
 		self.set_title(title, fontsize=self.title_font)
 		self.set_xlabel(xlabel, fontsize=self.xfont)
@@ -76,6 +88,11 @@ class lines:
 		if xlim is not None: plt.xlim(xlim)
 		if ylim is not None: plt.ylim(ylim)
 		
+		if vertical_axis_loc is not None:
+			plt.axvline(x=vertical_axis_loc, color=vertical_axis_color)
+		if horizontal_axis_loc is not None:
+			plt.axhline(y=horizontal_axis_loc, color=horizontal_axis_color)
+
 		plt.tight_layout()
 		if subplot is None:
 			if outpath is not None: plt.savefig(outpath)
@@ -97,6 +114,11 @@ class lines:
 		plt.text(xLoc, yLoc, textstr, fontsize=14, verticalalignment='top', bbox=props)
 
 
+	def fill_area(self, x=None, y=None, color='blue'):
+		if x is None: x = self.X
+		if y is None: y = self.Y
+
+		plt.fill_between(x, y, color=color)
 
 	def set_title(self, title, fontsize=16):
 		plt.title(title, fontsize=fontsize)
